tensap.approximation.tensor\_approximation package
==================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tensap.approximation.tensor_approximation.principal_component_analysis
   tensap.approximation.tensor_approximation.tensor_learning

Module contents
---------------

.. automodule:: tensap.approximation.tensor_approximation
   :members:
   :undoc-members:
   :show-inheritance:
